Page MenuHomeDevCentral

D787.id1989.diff
No OneTemporary

D787.id1989.diff

diff --git a/app/Services/Service.php b/app/Config/Services/Service.php
rename from app/Services/Service.php
rename to app/Config/Services/Service.php
--- a/app/Services/Service.php
+++ b/app/Config/Services/Service.php
@@ -1,6 +1,6 @@
<?php
-namespace Nasqueron\Notifications\Services;
+namespace Nasqueron\Notifications\Config\Services;
class Service {
/**
diff --git a/app/Services/Services.php b/app/Config/Services/Services.php
rename from app/Services/Services.php
rename to app/Config/Services/Services.php
--- a/app/Services/Services.php
+++ b/app/Config/Services/Services.php
@@ -1,6 +1,6 @@
<?php
-namespace Nasqueron\Notifications\Services;
+namespace Nasqueron\Notifications\Config\Services;
use Storage;
diff --git a/app/Providers/ServicesServiceProvider.php b/app/Providers/ServicesServiceProvider.php
--- a/app/Providers/ServicesServiceProvider.php
+++ b/app/Providers/ServicesServiceProvider.php
@@ -5,7 +5,7 @@
use Illuminate\Contracts\Foundation\Application;
use Illuminate\Support\ServiceProvider;
-use Nasqueron\Notifications\Services\Services;
+use Nasqueron\Notifications\Config\Services\Services;
class ServicesServiceProvider extends ServiceProvider {
/**
diff --git a/tests/Console/Commands/ConfigShowTest.php b/tests/Console/Commands/ConfigShowTest.php
--- a/tests/Console/Commands/ConfigShowTest.php
+++ b/tests/Console/Commands/ConfigShowTest.php
@@ -3,7 +3,7 @@
namespace Nasqueron\Notifications\Tests\Console\Commands;
use Nasqueron\Notifications\Config\Features;
-use Nasqueron\Notifications\Services\Service;
+use Nasqueron\Notifications\Config\Services\Service;
use Mockery;
diff --git a/tests/Console/Commands/PhabricatorProjectsMapTest.php b/tests/Console/Commands/PhabricatorProjectsMapTest.php
--- a/tests/Console/Commands/PhabricatorProjectsMapTest.php
+++ b/tests/Console/Commands/PhabricatorProjectsMapTest.php
@@ -2,7 +2,7 @@
namespace Nasqueron\Notifications\Tests\Console\Commands;
-use Nasqueron\Notifications\Services\Service;
+use Nasqueron\Notifications\Config\Services\Service;
class PhabricatorProjectsMapTest extends TestCase {
diff --git a/tests/Console/Commands/TestCase.php b/tests/Console/Commands/TestCase.php
--- a/tests/Console/Commands/TestCase.php
+++ b/tests/Console/Commands/TestCase.php
@@ -4,7 +4,7 @@
use Symfony\Component\Console\Tester\CommandTester;
-use Nasqueron\Notifications\Services\Service;
+use Nasqueron\Notifications\Config\Services\Service;
use Nasqueron\Notifications\Tests\TestCase as BaseTestCase;
use Artisan;
diff --git a/tests/Providers/ServicesServiceProviderTest.php b/tests/Providers/ServicesServiceProviderTest.php
--- a/tests/Providers/ServicesServiceProviderTest.php
+++ b/tests/Providers/ServicesServiceProviderTest.php
@@ -10,7 +10,7 @@
public function testType () {
$this->assertServiceInstanceOf(
- 'Nasqueron\Notifications\Services\Services',
+ "Nasqueron\Notifications\Config\Services\Services",
'services'
);
}
diff --git a/tests/Services/ServiceTest.php b/tests/Services/ServiceTest.php
--- a/tests/Services/ServiceTest.php
+++ b/tests/Services/ServiceTest.php
@@ -2,7 +2,7 @@
namespace Nasqueron\Notifications\Tests\Services;
-use Nasqueron\Notifications\Services\Service;
+use Nasqueron\Notifications\Config\Services\Service;
use Nasqueron\Notifications\Tests\TestCase;
class ServiceTest extends TestCase {
diff --git a/tests/Services/ServicesTest.php b/tests/Services/ServicesTest.php
--- a/tests/Services/ServicesTest.php
+++ b/tests/Services/ServicesTest.php
@@ -2,7 +2,7 @@
namespace Nasqueron\Notifications\Tests\Services;
-use Nasqueron\Notifications\Services\Services;
+use Nasqueron\Notifications\Config\Services\Services;
use Nasqueron\Notifications\Tests\TestCase;
class ServicesTest extends TestCase {
@@ -27,7 +27,7 @@
foreach ($actualServices as $service) {
$this->assertInstanceOf(
- 'Nasqueron\Notifications\Services\Service',
+ 'Nasqueron\Notifications\Config\Services\Service',
$service
);
}
@@ -38,7 +38,7 @@
$this->assertGreaterThan(0, $actualServices);
foreach ($actualServices as $service) {
$this->assertInstanceOf(
- 'Nasqueron\Notifications\Services\Service',
+ 'Nasqueron\Notifications\Config\Services\Service',
$service
);
$this->assertSame('GitHub', $service->gate);
@@ -50,7 +50,7 @@
$service = $this->services->findServiceByDoor('GitHub', 'Acme');
$this->assertInstanceOf(
- 'Nasqueron\Notifications\Services\Service',
+ 'Nasqueron\Notifications\Config\Services\Service',
$service
);
$this->assertSame('GitHub', $service->gate);
@@ -71,7 +71,7 @@
'https://phabricator.acme.tld'
);
$this->assertInstanceOf(
- 'Nasqueron\Notifications\Services\Service',
+ 'Nasqueron\Notifications\Config\Services\Service',
$service
);
$this->assertSame('Phabricator', $service->gate);

File Metadata

Mime Type
text/plain
Expires
Tue, Oct 1, 06:31 (20 h, 11 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
2167900
Default Alt Text
D787.id1989.diff (7 KB)

Event Timeline
diff --git a/app/Console/Commands/ConfigShow.php b/app/Console/Commands/ConfigShow.php
--- a/app/Console/Commands/ConfigShow.php
+++ b/app/Console/Commands/ConfigShow.php
@@ -5,7 +5,7 @@
use Illuminate\Console\Command;
use Nasqueron\Notifications\Config\Features;
-use Nasqueron\Notifications\Services\Service;
+use Nasqueron\Notifications\Config\Services\Service;
use Config;
use ProjectsMap;
@@ -41,7 +41,7 @@
/**
* Gets the services (defined in credentials.json) as table rows.
*
- * @return \Nasqueron\Notifications\Services\Service[]
+ * @return \Nasqueron\Notifications\Config\Services\Service[]
*/
protected function getServicesTableRows () : array {
$rows = [];
@@ -59,7 +59,7 @@
/**
* Gets service status.
*
* @param \Nasqueron\Notifications\Services\Service $service The service to check
* @return string A description of the issue if something is wrong; otherwise, "✓".
*/
protected function getServiveStatus (Service $service) : string {
@@ -59,7 +59,7 @@
* Gets service status.
*
- * @param \Nasqueron\Notifications\Services\Service $service The service to check
+ * @param \Nasqueron\Notifications\Config\Services\Service $service The service to check
* @return string A description of the issue if something is wrong; otherwise, "✓".
*/
diff --git a/app/Http/Controllers/Gate/GateController.php b/app/Http/Controllers/Gate/GateController.php
--- a/app/Http/Controllers/Gate/GateController.php
+++ b/app/Http/Controllers/Gate/GateController.php
@@ -3,8 +3,8 @@
namespace Nasqueron\Notifications\Http\Controllers\Gate;
use Nasqueron\Notifications\Config\Features;
+use Nasqueron\Notifications\Config\Services\Service;
use Nasqueron\Notifications\Http\Controllers\Controller;
-use Nasqueron\Notifications\Services\Service;
use Symfony\Component\HttpFoundation\Response as BaseResponse;
use Illuminate\View\View;
@@ -89,7 +89,7 @@
/**
* Gets service credentials for this gate and door
*
* @return Nasqueron\Notifications\Services\Service|null The service information is found; otherwise, null.
*/
public function getService () : ?Service {
return Services::findServiceByDoor(static::SERVICE_NAME, $this->door);
@@ -89,7 +89,7 @@
* Gets service credentials for this gate and door
*
- * @return Nasqueron\Notifications\Services\Service|null The service information is found; otherwise, null.
+ * @return \Nasqueron\Notifications\Config\Services\Service|null The service information is found; otherwise, null.
*/
public function getService () : ?Service {